Class: URIPattern::MatchResult
- Inherits:
-
Object
- Object
- URIPattern::MatchResult
- Defined in:
- lib/uri_pattern/match_result.rb
Instance Attribute Summary collapse
-
#fragment ⇒ Object
readonly
inputsis the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec. -
#hostname ⇒ Object
readonly
inputsis the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec. -
#inputs ⇒ Object
readonly
inputsis the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec. -
#password ⇒ Object
readonly
inputsis the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec. -
#pathname ⇒ Object
readonly
inputsis the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec. -
#port ⇒ Object
readonly
inputsis the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec. -
#protocol ⇒ Object
readonly
inputsis the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec. -
#query ⇒ Object
readonly
inputsis the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec. -
#username ⇒ Object
readonly
inputsis the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec.
Instance Method Summary collapse
-
#initialize(inputs:, protocol:, username:, password:, hostname:, port:, pathname:, query:, fragment:) ⇒ MatchResult
constructor
A new instance of MatchResult.
Constructor Details
#initialize(inputs:, protocol:, username:, password:, hostname:, port:, pathname:, query:, fragment:) ⇒ MatchResult
Returns a new instance of MatchResult.
12 13 14 15 16 17 18 19 20 21 22 23 |
# File 'lib/uri_pattern/match_result.rb', line 12 def initialize(inputs:, protocol:, username:, password:, hostname:, port:, pathname:, query:, fragment:) @inputs = inputs @protocol = protocol @username = username @password = password @hostname = hostname @port = port @pathname = pathname @query = query @fragment = fragment end |
Instance Attribute Details
#fragment ⇒ Object (readonly)
inputs is the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec.
9 10 11 |
# File 'lib/uri_pattern/match_result.rb', line 9 def fragment @fragment end |
#hostname ⇒ Object (readonly)
inputs is the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec.
9 10 11 |
# File 'lib/uri_pattern/match_result.rb', line 9 def hostname @hostname end |
#inputs ⇒ Object (readonly)
inputs is the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec.
9 10 11 |
# File 'lib/uri_pattern/match_result.rb', line 9 def inputs @inputs end |
#password ⇒ Object (readonly)
inputs is the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec.
9 10 11 |
# File 'lib/uri_pattern/match_result.rb', line 9 def password @password end |
#pathname ⇒ Object (readonly)
inputs is the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec.
9 10 11 |
# File 'lib/uri_pattern/match_result.rb', line 9 def pathname @pathname end |
#port ⇒ Object (readonly)
inputs is the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec.
9 10 11 |
# File 'lib/uri_pattern/match_result.rb', line 9 def port @port end |
#protocol ⇒ Object (readonly)
inputs is the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec.
9 10 11 |
# File 'lib/uri_pattern/match_result.rb', line 9 def protocol @protocol end |
#query ⇒ Object (readonly)
inputs is the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec.
9 10 11 |
# File 'lib/uri_pattern/match_result.rb', line 9 def query @query end |
#username ⇒ Object (readonly)
inputs is the array of arguments passed to #match: [input] or [input, base_url], mirroring URLPatternResult.inputs in the spec.
9 10 11 |
# File 'lib/uri_pattern/match_result.rb', line 9 def username @username end |